/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { IgrNumericYAxis } from './igr-numeric-y-axis';
import { IgrSeries } from './igr-series';
import { delegateCombine, delegateRemove } from "igniteui-react-core/ES2015/type";
import { brushToString, stringToBrush, toPoint, fromPoint, ensureBool, ensureEnum } from "igniteui-react-core/ES2015/componentUtil";
import { CategoryTransitionInMode_$type } from './CategoryTransitionInMode';
import { AssigningCategoryStyleEventArgs } from './igr-assigning-category-style-event-args';
import { FinancialEventArgs } from './igr-financial-event-args';
/**
 * Represents the base class for all financial indicator and overlay series.
*
* The `IgrFinancialSeries` represents the base class for all financial indicator and overlay series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*
*     <IgrCategoryXAxis name="xAxis" label="Date" />
*     <IgrNumericYAxis  name="yAxis" />
*
*
*     <IgrFinancialPriceSeries
*     name="series2"
*     xAxisName="xAxis"
*     yAxisName="yAxis"
*     displayType="Candlestick"
*     lowMemberPath="Low"
*     highMemberPath="High"
*     openMemberPath="Open"
*     closeMemberPath="Close"
*     volumeMemberPath="Volume" />
*
*  </IgrDataChart>
* ```
*/
export class IgrFinancialSeries extends IgrSeries {
    constructor(props) {
        super(props);
        this._assigningCategoryStyle = null;
        this._assigningCategoryStyle_wrapped = null;
        this._typical = null;
        this._typical_wrapped = null;
        this._typicalBasedOn = null;
        this._typicalBasedOn_wrapped = null;
    }
    set xAxisName(value) {
        this._xAxisName = value;
    }
    get xAxisName() {
        return this._xAxisName;
    }
    set yAxisName(value) {
        this._yAxisName = value;
    }
    get yAxisName() {
        return this._yAxisName;
    }
    bindAxes(axes) {
        for (let i = 0; i < axes.length; i++) {
            if (axes[i].name == this.xAxisName) {
                this.xAxis = axes[i];
            }
            if (axes[i].name == this.yAxisName) {
                this.yAxis = axes[i];
            }
        }
    }
    get i() {
        return this._implementation;
    }
    /**
 * Gets whether the current series is a financial type series.
*/
    get isFinancial() {
        return this.i.cr;
    }
    /**
     * Gets or sets the brush to use for negative portions of the series.
    *
    * The `negativeBrush` property is used to brush the negative portions of the series.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume"
    * 	negativeBrush="Red" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.negativeBrush="red";
    * ```
    */
    get negativeBrush() {
        return brushToString(this.i.o7);
    }
    set negativeBrush(v) {
        this.i.o7 = stringToBrush(v);
    }
    /**
     * Gets or sets the effective x-axis for the current FinancialSeries object.
    *
    * Use `xAxis` property to set effective x-axis for the current FinancialSeries object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume" />
    *  </IgrDataChart>
    * ```
    */
    get xAxis() {
        if (this.i.l1 == null) {
            return null;
        }
        return this.i.l1.externalObject;
    }
    set xAxis(v) {
        v == null ? this.i.l1 = null : this.i.l1 = v.i;
    }
    /**
     * Gets or sets the effective y-axis for the current FinancialSeries object.
    *
    * Use `yAxis` property to set the effective y-axis for the current FinancialSeries object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume" />
    *
    *  </IgrDataChart>
    * ```
    */
    get yAxis() {
        if (this.i.mm == null) {
            return null;
        }
        if (!this.i.mm.externalObject) {
            let e = new IgrNumericYAxis(null);
            e._implementation = this.i.mm;
            this.i.mm.externalObject = e;
        }
        return this.i.mm.externalObject;
    }
    set yAxis(v) {
        v == null ? this.i.mm = null : this.i.mm = v.i;
    }
    /**
     * Gets or sets the open mapping property for the current series object.
    *
    * The `openMemberPath` property is used for open mapping of the current series object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume" />
    *
    *  </IgrDataChart>
    * ```
    */
    get openMemberPath() {
        return this.i.oh;
    }
    set openMemberPath(v) {
        this.i.oh = v;
    }
    /**
     * Gets or sets the high mapping property for the current series object.
    *
    * Use `highMemberPath` propert for high mapping of the current series object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume" />
    *
    *  </IgrDataChart>
    * ```
    */
    get highMemberPath() {
        return this.i.n8;
    }
    set highMemberPath(v) {
        this.i.n8 = v;
    }
    /**
     * Gets or sets the low mapping property for the current series object.
    *
    * The `lowMemberPath` is used for low mapping property of the current series object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume" />
    *
    *  </IgrDataChart>
    * ```
    */
    get lowMemberPath() {
        return this.i.od;
    }
    set lowMemberPath(v) {
        this.i.od = v;
    }
    /**
     * Gets or sets the close mapping property for the current series object.
    *
    * Use `closeMemberPath` property for the close mapping of the current series object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume" />
    *
    *  </IgrDataChart>
    * ```
    */
    get closeMemberPath() {
        return this.i.n5;
    }
    set closeMemberPath(v) {
        this.i.n5 = v;
    }
    /**
     * Gets or sets the volume mapping property for the current series object.
    *
    * The `volumeMemberPath` property is used for the volume mapping property of the current series object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume" />
    *  </IgrDataChart>
    * ```
    */
    get volumeMemberPath() {
        return this.i.ol;
    }
    set volumeMemberPath(v) {
        this.i.ol = v;
    }
    /**
     * Gets or sets whether this category series should allow custom style overrides of its individual visuals.
    *
    * The `isCustomCategoryStyleAllowed` property is used to check if the category series should allow custom style.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume"
    * 	isCustomCategoryStyleAllowed="True" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.isCustomCategoryStyleAllowed= true;
    * ```
    */
    get isCustomCategoryStyleAllowed() {
        return this.i.m7;
    }
    set isCustomCategoryStyleAllowed(v) {
        this.i.m7 = ensureBool(v);
    }
    /**
     * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
     * Note: Transitions are not currently supported for stacked series.
    *
    * The `transitionInMode` property is used to gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume"
    * 	transitionInMode="Auto"/>
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.transitionInMode =CategoryTransitionInMode.Auto;
    * ```
    */
    get transitionInMode() {
        return this.i.mb;
    }
    set transitionInMode(v) {
        this.i.mb = ensureEnum(CategoryTransitionInMode_$type, v);
    }
    /**
     * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
     * Note: Transitions are not currently supported for stacked series.
    *
    * The `isTransitionInEnabled` property is used to check if the series should transition into the plot area when a new data source is assigned.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *
    *     <IgrFinancialPriceSeries
    *     name="series2"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     displayType="Candlestick"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     closeMemberPath="Close"
    *     volumeMemberPath="Volume"
    * 	isTransitionInEnabled="true" />
    *
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.isTransitionInEnabled= true;
    * ```
    */
    get isTransitionInEnabled() {
        return this.i.m8;
    }
    set isTransitionInEnabled(v) {
        this.i.m8 = ensureBool(v);
    }
    /**
     * Overridden by derived series classes to indicate when negative colors are supported or not.
    */
    get isNegativeColorSupported() {
        return this.i.cz;
    }
    getPreviousOrExactIndex(world, skipUnknowns) {
        let iv = this.i.fb(toPoint(world), skipUnknowns);
        return (iv);
    }
    getNextOrExactIndex(world, skipUnknowns) {
        let iv = this.i.e9(toPoint(world), skipUnknowns);
        return (iv);
    }
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    *
    * The `getOffsetValue` method returns the offset value for this series if grouped on a category axis.
    *
    * ```ts
    * number offset= series.getOffsetValue();
    * ```
    */
    getOffsetValue() {
        let iv = this.i.getOffsetValue();
        return (iv);
    }
    /**
     * Returns the width of the category grouping this series is in.
    
    *
    * The `getCategoryWidth` method returns the width of the category grouping this series is in.
    *
    * ```ts
    * number width = series.getCategoryWidth();
    * ```
    */
    getCategoryWidth() {
        let iv = this.i.getCategoryWidth();
        return (iv);
    }
    getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.le(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    getSeriesValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.ek(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesHighValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.eg(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesLowValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.ei(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesCloseValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.nt(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesOpenValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.nu(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesVolumeValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.nv(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesHighValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.la(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    getSeriesLowValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.lc(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    getSeriesOpenValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.o9(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    getSeriesCloseValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.o8(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    getSeriesVolumeValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.pa(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    *
    * Use `canUseAsYAxis` method to determine if the object can be used as YAxis.
    *
    * ```ts
    *   boolean canY =series.canUseAsYAxis(yAxis);
    * ```
    */
    canUseAsYAxis(axis) {
        let iv = this.i.m3(axis);
        return (iv);
    }
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    *
    * Use `canUseAsXAxis` method to determine if the object can be used as XAxis.
    *
    * ```ts
    *   boolean canX =series.canUseAsXAxis(xAxis);
    * ```
    */
    canUseAsXAxis(axis) {
        let iv = this.i.m2(axis);
        return (iv);
    }
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    *
    * The `getExactItemIndex` method gets the precise item index, if possible, based on the closeness to the previous or next whole integer.
    *
    * If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    *
    * ```ts
    * number index = series.getExactItemIndex(world);
    * ```
    */
    getExactItemIndex(world) {
        let iv = this.i.d8(toPoint(world));
        return (iv);
    }
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    *
    * The `getItemIndex` method gets the index of the item that resides at the provided world coordinates.
    *
    * ```ts
    * number itemindex= series.getItemIndex(world);
    * ```
    */
    getItemIndex(world) {
        let iv = this.i.e5(toPoint(world));
        return (iv);
    }
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    *
    * The `getItem` method gets the item that is the best match for the specified world coordinates.
    */
    getItem(world) {
        let iv = this.i.fm(toPoint(world));
        return (iv);
    }
    setNegativeColors(negativeBrush, negativeOutline) {
        this.i.jb(stringToBrush(negativeBrush), stringToBrush(negativeOutline));
    }
    /**
     * Event raised when Assigning Category Style
    *
    * The `AssigningCategoryStyle` event raised when assigning Category Style.
    *
    * ```ts
    * series.assigningCategoryStyle= this.chart_AssigningCategoryStyle;
    * chart_AssigningCategoryStyle(sender :any,args: AssigningCategoryStyleEventArgs )
    *   {
    *
    *
    *   }
    * ```
    */
    get assigningCategoryStyle() {
        return this._assigningCategoryStyle;
    }
    set assigningCategoryStyle(ev) {
        if (this._assigningCategoryStyle_wrapped !== null) {
            this.i.assigningCategoryStyle = delegateRemove(this.i.assigningCategoryStyle, this._assigningCategoryStyle_wrapped);
            this._assigningCategoryStyle_wrapped = null;
            this._assigningCategoryStyle = null;
        }
        this._assigningCategoryStyle = ev;
        this._assigningCategoryStyle_wrapped = (o, e) => {
            let outerArgs = new AssigningCategoryStyleEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeAssigningCategoryStyle) {
                this.beforeAssigningCategoryStyle(this, outerArgs);
            }
            if (this._assigningCategoryStyle) {
                this._assigningCategoryStyle(this, outerArgs);
            }
        };
        this.i.assigningCategoryStyle = delegateCombine(this.i.assigningCategoryStyle, this._assigningCategoryStyle_wrapped);
    }
    /**
     * Handle this event in order to perform a custom typical price calculation.
    *
    * Use `Typical` event to perform a custom typical price calculation.
    *
    * ```ts
    * series.typical= this.chart_typical;
    *
    *   chart_typical(sender :any,args: FinancialEventArgs )
    *   {
    *
    *
    *   }
    * ```
    */
    get typical() {
        return this._typical;
    }
    set typical(ev) {
        if (this._typical_wrapped !== null) {
            this.i.typical = delegateRemove(this.i.typical, this._typical_wrapped);
            this._typical_wrapped = null;
            this._typical = null;
        }
        this._typical = ev;
        this._typical_wrapped = (o, e) => {
            let outerArgs = new FinancialEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeTypical) {
                this.beforeTypical(this, outerArgs);
            }
            if (this._typical) {
                this._typical(this, outerArgs);
            }
        };
        this.i.typical = delegateCombine(this.i.typical, this._typical_wrapped);
    }
    /**
     * Handle this event in order to specify which columns the Typical price calculation is based on.
    *
    * Use `TypicalBasedOn` event to specify which columns the Typical price calculation is based on.
    *
    * ```ts
    *    series.typicalBasedOn= this.chart_typicalBasedOn;
    *     chart_typicalBasedOn(sender :any,args: FinancialEventArgs )
    *   {
    *
    *   }
    * ```
    */
    get typicalBasedOn() {
        return this._typicalBasedOn;
    }
    set typicalBasedOn(ev) {
        if (this._typicalBasedOn_wrapped !== null) {
            this.i.typicalBasedOn = delegateRemove(this.i.typicalBasedOn, this._typicalBasedOn_wrapped);
            this._typicalBasedOn_wrapped = null;
            this._typicalBasedOn = null;
        }
        this._typicalBasedOn = ev;
        this._typicalBasedOn_wrapped = (o, e) => {
            let outerArgs = new FinancialEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeTypicalBasedOn) {
                this.beforeTypicalBasedOn(this, outerArgs);
            }
            if (this._typicalBasedOn) {
                this._typicalBasedOn(this, outerArgs);
            }
        };
        this.i.typicalBasedOn = delegateCombine(this.i.typicalBasedOn, this._typicalBasedOn_wrapped);
    }
}
