import { IgPoint } from "igniteui-react-core/ES2015/IgPoint";
import { IgrCategoryAxisBase } from './igr-category-axis-base';
import { IgrNumericYAxis } from './igr-numeric-y-axis';
import { IgrRangeCategorySeries, IIgrRangeCategorySeriesProps } from './igr-range-category-series';
import { IgrAxis } from './igr-axis';
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
/**
 * Base class for ranged category series with a category X-axis and a numeric Y-axis.
*
* Instantiate HorizontalAnchoredCategorySeries
*/
export declare abstract class IgrHorizontalRangeCategorySeries<P extends IIgrHorizontalRangeCategorySeriesProps = IIgrHorizontalRangeCategorySeriesProps> extends IgrRangeCategorySeries<P> {
    constructor(props: P);
    private _xAxisName;
    xAxisName: string;
    private _yAxisName;
    yAxisName: string;
    bindAxes(axes: IgrAxis[]): void;
    readonly i: HorizontalRangeCategorySeries;
    /**
 * Gets or sets the effective x-axis for the current CategorySeries object.
*
* Instantiate xAxis
*/
    xAxis: IgrCategoryAxisBase;
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    *
    * Instantiate yAxis
    */
    yAxis: IgrNumericYAxis;
    /**
     * Checks if this series is a range series
    *
    * You can use the `isRange` to get the current series is a range type series.
    *
    * <!-- Angular JS -->
    *
    *       var r = this.series.isRange;
    *
    * <!-- Ignite JS -->
    *
    *      N/A
    */
    readonly isRange: boolean;
    /**
 * Returns the offset value for this series if grouped on a category axis.

*
* You can use the `getOffsetValue` to get the offset value for this series if grouped on a category axis.
*
* <!-- Angular JS -->
*
*       var g = series.getOffsetValue();
*
* <!-- Ignite JS -->
*
*      N/A
*/
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    *
    * You can use the `getCategoryWidth` to get the width of the category grouping a series is in.
    *
    * <!-- Angular JS -->
    *
    *      var x = this.financialSeries.CanUseAsXAxis(this.xAxis);
    *
    * <!-- Ignite JS -->
    *
    *      N/A
    */
    getCategoryWidth(): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesLowValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesLowValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    *
    * You can use the `canUseAsYAxis` method to determine if object can be used as YAxis
    *
    * <!-- Ignite JS -->
    *
    *      N/A
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    *
    * You can use the `canUseAsXAxis` method to determine if object can be used as XAxis
    *
    * <!-- Angular JS -->
    *
    *      var x = this.financialSeries.CanUseAsXAxis(this.xAxis);
    *
    * <!-- Ignite JS -->
    *
    *      N/A
    */
    canUseAsXAxis(axis: any): boolean;
}
export interface IIgrHorizontalRangeCategorySeriesProps extends IIgrRangeCategorySeriesProps {
    xAxisName?: string;
    yAxisName?: string;
    /**
 * Gets or sets the effective x-axis for the current CategorySeries object.
*
* Instantiate xAxis
*/
    xAxis?: IgrCategoryAxisBase;
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    *
    * Instantiate yAxis
    */
    yAxis?: IgrNumericYAxis;
}
