import { UnknownValuePlotting } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { LineSeries } from "./LineSeries";
/**
 * Represents a IgxDataChartComponent line series.
 * Displays trend over time or ordered categories.Useful when there are many data points and the order is important.
*
* `IgrLineSeries` belongs to a group of `IgrCategorySeries` and it is rendered using a collection of points connected by straight line segments.
*/
export declare class IgrLineSeries extends IgrHorizontalAnchoredCategorySeries<IIgrLineSeriesProps> {
    protected createImplementation(): LineSeries;
    readonly i: LineSeries;
    constructor(props: IIgrLineSeriesProps);
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Gets whether the `IgrSeries` shows an area or a line shape.
    *
    * ```ts
    * let isAreaOrLine: boolean = series.isAreaOrLine;
    * ```
    */
    readonly isAreaOrLine: boolean;
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Determines how unknown values will be plotted for the `IgrSeries`. This can be set to `LinearInterpolate` to create a continous shape or `DontPlot` to create breaks in the series.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```ts
    * series.unknownValuePlotting = UnknownValuePlotting.LinearInterpolate;
    * ```
    */
    unknownValuePlotting: UnknownValuePlotting;
}
export interface IIgrLineSeriesProps extends IIgrHorizontalAnchoredCategorySeriesProps {
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Determines how unknown values will be plotted for the `IgrSeries`. This can be set to `LinearInterpolate` to create a continous shape or `DontPlot` to create breaks in the series.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```ts
    * series.unknownValuePlotting = UnknownValuePlotting.LinearInterpolate;
    * ```
    */
    unknownValuePlotting?: UnknownValuePlotting | string;
}
