import { IgrStrategyBasedIndicator, IIgrStrategyBasedIndicatorProps } from "./igr-strategy-based-indicator";
import { PercentagePriceOscillatorIndicator } from "./PercentagePriceOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent percentage price oscillator series.
 * Default required members: High, Low, Volume
*
* You can use the `IgrPercentagePriceOscillatorIndicator` to show the difference between two moving averages.
*/
export declare class IgrPercentagePriceOscillatorIndicator extends IgrStrategyBasedIndicator<IIgrPercentagePriceOscillatorIndicatorProps> {
    protected createImplementation(): PercentagePriceOscillatorIndicator;
    readonly i: PercentagePriceOscillatorIndicator;
    constructor(props: IIgrPercentagePriceOscillatorIndicatorProps);
    /**
     * Gets or sets the short moving average period for the current PercentagePriceOscillatorIndicator object.
     * The typical, and initial, value for short PPO periods is 10.
    *
    * You can use the `shortPeriod` to set the short moving average period.
    *
    * ```ts
    * this.series.shortPeriod = 10;
    * ```
    */
    shortPeriod: number;
    /**
     * Gets or sets the long moving average period for the current PercentagePriceOscillatorIndicator object.
     * The typical, and initial, value for long PVO periods is 30.
    *
    * You can use the `longPeriod` to set the long moving average period.
    *
    * ```ts
    * this.series.longPeriod = 30;
    * ```
    */
    longPeriod: number;
}
export interface IIgrPercentagePriceOscillatorIndicatorProps extends IIgrStrategyBasedIndicatorProps {
    /**
     * Gets or sets the short moving average period for the current PercentagePriceOscillatorIndicator object.
     * The typical, and initial, value for short PPO periods is 10.
    *
    * You can use the `shortPeriod` to set the short moving average period.
    *
    * ```ts
    * this.series.shortPeriod = 10;
    * ```
    */
    shortPeriod?: number | string;
    /**
     * Gets or sets the long moving average period for the current PercentagePriceOscillatorIndicator object.
     * The typical, and initial, value for long PVO periods is 30.
    *
    * You can use the `longPeriod` to set the long moving average period.
    *
    * ```ts
    * this.series.longPeriod = 30;
    * ```
    */
    longPeriod?: number | string;
}
