import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { PercentagePriceOscillatorIndicator } from "./PercentagePriceOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent percentage price oscillator series.
 * Default required members: High, Low, Volume
*
* You can use the `IgrPercentagePriceOscillatorIndicator` to show the difference between two moving averages.
*/
export class IgrPercentagePriceOscillatorIndicator extends IgrStrategyBasedIndicator {
    createImplementation() {
        return new PercentagePriceOscillatorIndicator();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the short moving average period for the current PercentagePriceOscillatorIndicator object.
     * The typical, and initial, value for short PPO periods is 10.
    *
    * You can use the `shortPeriod` to set the short moving average period.
    *
    * ```ts
    * this.series.shortPeriod = 10;
    * ```
    */
    get shortPeriod() {
        return this.i.shortPeriod;
    }
    set shortPeriod(v) {
        this.i.shortPeriod = +v;
    }
    /**
     * Gets or sets the long moving average period for the current PercentagePriceOscillatorIndicator object.
     * The typical, and initial, value for long PVO periods is 30.
    *
    * You can use the `longPeriod` to set the long moving average period.
    *
    * ```ts
    * this.series.longPeriod = 30;
    * ```
    */
    get longPeriod() {
        return this.i.longPeriod;
    }
    set longPeriod(v) {
        this.i.longPeriod = +v;
    }
}
