import { IgrCategorySeries } from "./igr-category-series";
/**
 * Represents the base class for all IgxDataChartComponent ranged category/value series.
*
* The `IgrRangeCategorySeries` represents the base class for all IgxDataChartComponent ranged category/value series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRangeColumnSeries
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*/
export class IgrRangeCategorySeries extends IgrCategorySeries {
    constructor(props) {
        super(props);
    }
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the value mapping property for the current series object.
    *
    * The `lowMemberPath` is used for low mapping property of the current series object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *     <IgrCategoryXAxis name="xAxis" label="Year" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *     <IgrRangeColumnSeries
    *         name="series1"
    *         xAxisName="xAxis"
    *         yAxisName="yAxis"
    *         highMemberPath="High"
    *         lowMemberPath="Low" />
    *  </IgrDataChart>
    * ```
    */
    get lowMemberPath() {
        return this.i.oz;
    }
    set lowMemberPath(v) {
        this.i.oz = v;
    }
    /**
     * Gets or sets the value mapping property for the current series object.
    *
    * Use `highMemberPath` propert for high mapping of the current series object.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *     <IgrCategoryXAxis name="xAxis" label="Year" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *     <IgrRangeColumnSeries
    *         name="series1"
    *         xAxisName="xAxis"
    *         yAxisName="yAxis"
    *         highMemberPath="High"
    *         lowMemberPath="Low" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.highMemberPath = "high";
    * ```
    */
    get highMemberPath() {
        return this.i.ow;
    }
    set highMemberPath(v) {
        this.i.ow = v;
    }
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    *
    * `scrollIntoView` method Scrolls the series to display the item for the specified data item.
    */
    scrollIntoView(item) {
        let iv = this.i.c8(item);
        return (iv);
    }
}
