import { Style } from "igniteui-react-core/ES2015/igr-style";
import { MarkerType_$type } from "./MarkerType";
import { CollisionAvoidanceType_$type } from "./CollisionAvoidanceType";
import { IgrShapeSeriesBase } from "./igr-shape-series-base";
import { ScatterPolygonSeries } from "./ScatterPolygonSeries";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Series class which renders polygons as Paths based on lists of points in the ItemsSource.
*/
export class IgrScatterPolygonSeries extends IgrShapeSeriesBase {
    createImplementation() {
        return new ScatterPolygonSeries();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Returns whether the current series supports visual markers.
    */
    get hasMarkers() {
        return this.i.hasMarkers;
    }
    /**
     * The StyleSelector which is used to select a style for each Shape.
    */
    get shapeStyleSelector() {
        return this.i.nb;
    }
    set shapeStyleSelector(v) {
        this.i.nb = v;
    }
    /**
     * The default style to apply to all Shapes in the series.
    */
    get shapeStyle() {
        if (this.i.n8 == null) {
            return null;
        }
        if (!this.i.n8.externalObject) {
            let e = new Style();
            e._implementation = this.i.n8;
            this.i.n8.externalObject = e;
        }
        return this.i.n8.externalObject;
    }
    set shapeStyle(v) {
        v == null ? this.i.n8 = null : this.i.n8 = v.i;
    }
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType() {
        return this.i.m6;
    }
    set markerType(v) {
        this.i.m6 = ensureEnum(MarkerType_$type, v);
    }
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate() {
        return this.i.nq;
    }
    set markerTemplate(v) {
        this.i.nq = v;
    }
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate() {
        return this.i.np;
    }
    set actualMarkerTemplate(v) {
        this.i.np = v;
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush() {
        return brushToString(this.i.n4);
    }
    set markerBrush(v) {
        this.i.n4 = stringToBrush(v);
    }
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush() {
        return brushToString(this.i.n2);
    }
    set actualMarkerBrush(v) {
        this.i.n2 = stringToBrush(v);
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline() {
        return brushToString(this.i.n5);
    }
    set markerOutline(v) {
        this.i.n5 = stringToBrush(v);
    }
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline() {
        return brushToString(this.i.n3);
    }
    set actualMarkerOutline(v) {
        this.i.n3 = stringToBrush(v);
    }
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    get markerCollisionAvoidance() {
        return this.i.m5;
    }
    set markerCollisionAvoidance(v) {
        this.i.m5 = ensureEnum(CollisionAvoidanceType_$type, v);
    }
}
