import { IgrNumericXAxis } from './igr-numeric-x-axis';
import { IgrNumericYAxis } from './igr-numeric-y-axis';
import { IgrSeries, IIgrSeriesProps } from './igr-series';
import { IgrAxis } from './igr-axis';
import { ScatterTriangulationSeries } from "./ScatterTriangulationSeries";
import { TriangulationStatusEventArgs } from "igniteui-react-core/ES2015/igr-triangulation-status-event-args";
/**
 * Base class for series which triangulate XY data prior to rendering.
*/
export declare abstract class IgrScatterTriangulationSeries<P extends IIgrScatterTriangulationSeriesProps = IIgrScatterTriangulationSeriesProps> extends IgrSeries<P> {
    constructor(props: P);
    private _xAxisName;
    xAxisName: string;
    private _yAxisName;
    yAxisName: string;
    bindAxes(axes: IgrAxis[]): void;
    readonly i: ScatterTriangulationSeries;
    /**
 * The name of the property from which to extract the X-coordinate for each item in the ItemsSource.
*/
    xMemberPath: string;
    /**
     * The name of the property from which to extract the Y-coordinate for each item in the ItemsSource.
    */
    yMemberPath: string;
    /**
     * The X-Axis for this series.
    */
    xAxis: IgrNumericXAxis;
    /**
     * The Y-Axis for this series.
    */
    yAxis: IgrNumericYAxis;
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the first vertex point in the ItemsSource.
    */
    triangleVertexMemberPath1: string;
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the second vertex point in the ItemsSource.
    */
    triangleVertexMemberPath2: string;
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the third vertex point in the ItemsSource.
    */
    triangleVertexMemberPath3: string;
    /**
     * Gets whether or not this series is a shape series
    */
    readonly isShape: boolean;
    /**
 * Determine if object can be used as YAxis

* @param axis  * The object to check
*/
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
    private _triangulationStatusChanged;
    private _triangulationStatusChanged_wrapped;
    /**
     * Raised when the status of an ongoing Triangulation has changed.
    */
    triangulationStatusChanged: (s: IgrScatterTriangulationSeries, e: TriangulationStatusEventArgs) => void;
}
export interface IIgrScatterTriangulationSeriesProps extends IIgrSeriesProps {
    xAxisName?: string;
    yAxisName?: string;
    /**
 * The name of the property from which to extract the X-coordinate for each item in the ItemsSource.
*/
    xMemberPath?: string;
    /**
     * The name of the property from which to extract the Y-coordinate for each item in the ItemsSource.
    */
    yMemberPath?: string;
    /**
     * The X-Axis for this series.
    */
    xAxis?: IgrNumericXAxis;
    /**
     * The Y-Axis for this series.
    */
    yAxis?: IgrNumericYAxis;
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the first vertex point in the ItemsSource.
    */
    triangleVertexMemberPath1?: string;
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the second vertex point in the ItemsSource.
    */
    triangleVertexMemberPath2?: string;
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the third vertex point in the ItemsSource.
    */
    triangleVertexMemberPath3?: string;
    /**
 * Raised when the status of an ongoing Triangulation has changed.
*/
    triangulationStatusChanged?: (s: IgrScatterTriangulationSeries, e: TriangulationStatusEventArgs) => void;
}
