import { IgrNumericXAxis } from './igr-numeric-x-axis';
import { IgrNumericYAxis } from './igr-numeric-y-axis';
import { IgrSeries, IIgrSeriesProps } from './igr-series';
import { IgrAxis } from './igr-axis';
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleShapeEventArgs } from './igr-style-shape-event-args';
/**
 * Series class for rendering polygons.
*/
export declare abstract class IgrShapeSeriesBase<P extends IIgrShapeSeriesBaseProps = IIgrShapeSeriesBaseProps> extends IgrSeries<P> {
    constructor(props: P);
    private _xAxisName;
    xAxisName: string;
    private _yAxisName;
    yAxisName: string;
    bindAxes(axes: IgrAxis[]): void;
    readonly i: ShapeSeriesBase;
    /**
 * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
 * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
*/
    shapeMemberPath: string;
    /**
     * Gets or sets the effective x-axis for the current ScatterBase object.
    */
    xAxis: IgrNumericXAxis;
    /**
     * Gets or sets the effective y-axis for the current ScatterBase object.
    */
    yAxis: IgrNumericYAxis;
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of ScatterPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    shapeFilterResolution: number;
    /**
     * Gets whether or not this series is a shape series
    */
    readonly isShape: boolean;
    /**
 * Determine if object can be used as YAxis

* @param axis  * The object to check
*/
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
    private _styleShape;
    private _styleShape_wrapped;
    /**
     * Raised when tile's image URI should be provided
    */
    styleShape: (s: IgrShapeSeriesBase, e: StyleShapeEventArgs) => void;
}
export interface IIgrShapeSeriesBaseProps extends IIgrSeriesProps {
    xAxisName?: string;
    yAxisName?: string;
    /**
 * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
 * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
*/
    shapeMemberPath?: string;
    /**
     * Gets or sets the effective x-axis for the current ScatterBase object.
    */
    xAxis?: IgrNumericXAxis;
    /**
     * Gets or sets the effective y-axis for the current ScatterBase object.
    */
    yAxis?: IgrNumericYAxis;
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of ScatterPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    shapeFilterResolution?: number | string;
    /**
 * Raised when tile's image URI should be provided
*/
    styleShape?: (s: IgrShapeSeriesBase, e: StyleShapeEventArgs) => void;
}
