import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { StochRSIIndicator } from "./StochRSIIndicator";
/**
 * Represents a IgxDataChartComponent StochRSI indicator series.
 * Default required members: Close
*
* `IgrStochRSIIndicator` or Stochastic Relative Strength IndexI Indicator (SRSI) measures when a security is overbought or oversold within a specified period of time. The values range from 0 to 1. The StochRSI Indicator is calculated by applying the Stochastic Oscillator formula to RelativeStrengthIndexIndicator (RSI) data.
*
* Using this indicator requires setting the `CloseMemberPath`.
*/
export class IgrStochRSIIndicator extends IgrStrategyBasedIndicator {
    createImplementation() {
        return new StochRSIIndicator();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the moving average period for the current StochRSIIndicator object.
     * The typical, and initial, value for StochRSI periods is 14.
    */
    get period() {
        return this.i.qq;
    }
    set period(v) {
        this.i.qq = +v;
    }
}
