import * as tslib_1 from "tslib";
import { TrendLineType_$type } from "igniteui-react-core/ES5/TrendLineType";
import { IgrRadialBase } from "./igr-radial-base";
import { ensureEnum, brushToString, stringToBrush, toPoint, fromPoint } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent anchored radial category series.
*/
var IgrAnchoredRadialSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrAnchoredRadialSeries, _super);
    function IgrAnchoredRadialSeries(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnchoredRadialSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnchoredRadialSeries.prototype, "valueMemberPath", {
        /**
         * Gets or sets the item path that provides the values for the current series.
        */
        get: function () {
            return this.i.n1;
        },
        set: function (v) {
            this.i.n1 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnchoredRadialSeries.prototype, "trendLineType", {
        /**
         * Gets or sets the trend type for the current series object.
        */
        get: function () {
            return this.i.nn;
        },
        set: function (v) {
            this.i.nn = ensureEnum(TrendLineType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnchoredRadialSeries.prototype, "trendLineBrush", {
        /**
         * Gets or sets the brush that specifies how to the current series
         * object's Trend line is drawn.
        */
        get: function () {
            return brushToString(this.i.of);
        },
        set: function (v) {
            this.i.of = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnchoredRadialSeries.prototype, "actualTrendLineBrush", {
        /**
         * Gets the effective TrendLineBrush for this series.
        */
        get: function () {
            return brushToString(this.i.oe);
        },
        set: function (v) {
            this.i.oe = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnchoredRadialSeries.prototype, "trendLineThickness", {
        /**
         * Gets or sets the thickness of the current series object's trend line.
        */
        get: function () {
            return this.i.nx;
        },
        set: function (v) {
            this.i.nx = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnchoredRadialSeries.prototype, "trendLinePeriod", {
        /**
         * Gets or sets the trend line period for the current series.
         * The typical, and initial, value for bollinger band periods is 20.
        */
        get: function () {
            return this.i.ny;
        },
        set: function (v) {
            this.i.ny = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnchoredRadialSeries.prototype, "trendLineZIndex", {
        /**
         * Sets or Gets the Z index of the trendline.
        */
        get: function () {
            return this.i.nz;
        },
        set: function (v) {
            this.i.nz = +v;
        },
        enumerable: true,
        configurable: true
    });
    IgrAnchoredRadialSeries.prototype.getPreviousOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.fb(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgrAnchoredRadialSeries.prototype.getNextOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.e9(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgrAnchoredRadialSeries.prototype.getSeriesValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ek(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrAnchoredRadialSeries.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.le(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    IgrAnchoredRadialSeries.prototype.getOffsetValue = function () {
        var iv = this.i.getOffsetValue();
        return (iv);
    };
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    IgrAnchoredRadialSeries.prototype.getCategoryWidth = function () {
        var iv = this.i.getCategoryWidth();
        return (iv);
    };
    /**
     * Scrolls the specified item into the view.
    
    * @param item  * The item to scroll into view.
    */
    IgrAnchoredRadialSeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    return IgrAnchoredRadialSeries;
}(IgrRadialBase));
export { IgrAnchoredRadialSeries };
