import * as tslib_1 from "tslib";
import { IgrFragmentBase } from "./igr-fragment-base";
import { ColumnFragment } from "./ColumnFragment";
import { toPoint, fromRect } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents one part of a StackedColumnSeries.
*/
var IgrColumnFragment = /** @class */ (function (_super) {
    tslib_1.__extends(IgrColumnFragment, _super);
    function IgrColumnFragment(props) {
        return _super.call(this, props) || this;
    }
    IgrColumnFragment.prototype.createImplementation = function () {
        return new ColumnFragment();
    };
    Object.defineProperty(IgrColumnFragment.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrColumnFragment.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.qm;
        },
        set: function (v) {
            this.i.qm = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrColumnFragment.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.qn;
        },
        set: function (v) {
            this.i.qn = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrColumnFragment.prototype, "fragmentXAxis", {
        /**
         * Gets or sets the effective x-axis for this series.
        */
        get: function () {
            if (this.i.fragmentXAxis == null) {
                return null;
            }
            return this.i.fragmentXAxis.externalObject;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrColumnFragment.prototype, "fragmentYAxis", {
        /**
         * Gets or sets the effective y-axis for this series.
        */
        get: function () {
            if (this.i.fragmentYAxis == null) {
                return null;
            }
            return this.i.fragmentYAxis.externalObject;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    IgrColumnFragment.prototype.getSeriesValueBoundingBox = function (world) {
        var iv = this.i.ln(toPoint(world));
        return fromRect(iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrColumnFragment.prototype.getItem = function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    IgrColumnFragment.prototype.getItemIndex = function (world) {
        var iv = this.i.e5(toPoint(world));
        return (iv);
    };
    return IgrColumnFragment;
}(IgrFragmentBase));
export { IgrColumnFragment };
