/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { IgrNumericYAxis } from './igr-numeric-y-axis';
import { IgrSeries } from './igr-series';
import { delegateCombine, delegateRemove } from "igniteui-react-core/ES5/type";
import { brushToString, stringToBrush, toPoint, fromPoint, ensureBool, ensureEnum } from "igniteui-react-core/ES5/componentUtil";
import { CategoryTransitionInMode_$type } from './CategoryTransitionInMode';
import { AssigningCategoryStyleEventArgs } from './igr-assigning-category-style-event-args';
import { FinancialEventArgs } from './igr-financial-event-args';
/**
 * Represents the base class for all financial indicator and overlay series.
*
* The `IgrFinancialSeries` represents the base class for all financial indicator and overlay series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*
*     <IgrCategoryXAxis name="xAxis" label="Date" />
*     <IgrNumericYAxis  name="yAxis" />
*
*
*     <IgrFinancialPriceSeries
*     name="series2"
*     xAxisName="xAxis"
*     yAxisName="yAxis"
*     displayType="Candlestick"
*     lowMemberPath="Low"
*     highMemberPath="High"
*     openMemberPath="Open"
*     closeMemberPath="Close"
*     volumeMemberPath="Volume" />
*
*  </IgrDataChart>
* ```
*/
var IgrFinancialSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrFinancialSeries, _super);
    function IgrFinancialSeries(props) {
        var _this = _super.call(this, props) || this;
        _this._assigningCategoryStyle = null;
        _this._assigningCategoryStyle_wrapped = null;
        _this._typical = null;
        _this._typical_wrapped = null;
        _this._typicalBasedOn = null;
        _this._typicalBasedOn_wrapped = null;
        return _this;
    }
    Object.defineProperty(IgrFinancialSeries.prototype, "xAxisName", {
        get: function () {
            return this._xAxisName;
        },
        set: function (value) {
            this._xAxisName = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "yAxisName", {
        get: function () {
            return this._yAxisName;
        },
        set: function (value) {
            this._yAxisName = value;
        },
        enumerable: true,
        configurable: true
    });
    IgrFinancialSeries.prototype.bindAxes = function (axes) {
        for (var i = 0; i < axes.length; i++) {
            if (axes[i].name == this.xAxisName) {
                this.xAxis = axes[i];
            }
            if (axes[i].name == this.yAxisName) {
                this.yAxis = axes[i];
            }
        }
    };
    Object.defineProperty(IgrFinancialSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "isFinancial", {
        /**
     * Gets whether the current series is a financial type series.
    */
        get: function () {
            return this.i.cr;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "negativeBrush", {
        /**
         * Gets or sets the brush to use for negative portions of the series.
        *
        * The `negativeBrush` property is used to brush the negative portions of the series.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume"
        * 	negativeBrush="Red" />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * series.negativeBrush="red";
        * ```
        */
        get: function () {
            return brushToString(this.i.o7);
        },
        set: function (v) {
            this.i.o7 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "xAxis", {
        /**
         * Gets or sets the effective x-axis for the current FinancialSeries object.
        *
        * Use `xAxis` property to set effective x-axis for the current FinancialSeries object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume" />
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            if (this.i.l1 == null) {
                return null;
            }
            return this.i.l1.externalObject;
        },
        set: function (v) {
            v == null ? this.i.l1 = null : this.i.l1 = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "yAxis", {
        /**
         * Gets or sets the effective y-axis for the current FinancialSeries object.
        *
        * Use `yAxis` property to set the effective y-axis for the current FinancialSeries object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume" />
        *
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            if (this.i.mm == null) {
                return null;
            }
            if (!this.i.mm.externalObject) {
                var e = new IgrNumericYAxis(null);
                e._implementation = this.i.mm;
                this.i.mm.externalObject = e;
            }
            return this.i.mm.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mm = null : this.i.mm = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "openMemberPath", {
        /**
         * Gets or sets the open mapping property for the current series object.
        *
        * The `openMemberPath` property is used for open mapping of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume" />
        *
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.oh;
        },
        set: function (v) {
            this.i.oh = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "highMemberPath", {
        /**
         * Gets or sets the high mapping property for the current series object.
        *
        * Use `highMemberPath` propert for high mapping of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume" />
        *
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.n8;
        },
        set: function (v) {
            this.i.n8 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "lowMemberPath", {
        /**
         * Gets or sets the low mapping property for the current series object.
        *
        * The `lowMemberPath` is used for low mapping property of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume" />
        *
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.od;
        },
        set: function (v) {
            this.i.od = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "closeMemberPath", {
        /**
         * Gets or sets the close mapping property for the current series object.
        *
        * Use `closeMemberPath` property for the close mapping of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume" />
        *
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.n5;
        },
        set: function (v) {
            this.i.n5 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "volumeMemberPath", {
        /**
         * Gets or sets the volume mapping property for the current series object.
        *
        * The `volumeMemberPath` property is used for the volume mapping property of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume" />
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.ol;
        },
        set: function (v) {
            this.i.ol = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "isCustomCategoryStyleAllowed", {
        /**
         * Gets or sets whether this category series should allow custom style overrides of its individual visuals.
        *
        * The `isCustomCategoryStyleAllowed` property is used to check if the category series should allow custom style.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume"
        * 	isCustomCategoryStyleAllowed="True" />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * series.isCustomCategoryStyleAllowed= true;
        * ```
        */
        get: function () {
            return this.i.m7;
        },
        set: function (v) {
            this.i.m7 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "transitionInMode", {
        /**
         * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
         * Note: Transitions are not currently supported for stacked series.
        *
        * The `transitionInMode` property is used to gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume"
        * 	transitionInMode="Auto"/>
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * series.transitionInMode =CategoryTransitionInMode.Auto;
        * ```
        */
        get: function () {
            return this.i.mb;
        },
        set: function (v) {
            this.i.mb = ensureEnum(CategoryTransitionInMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "isTransitionInEnabled", {
        /**
         * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
         * Note: Transitions are not currently supported for stacked series.
        *
        * The `isTransitionInEnabled` property is used to check if the series should transition into the plot area when a new data source is assigned.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *
        *     <IgrFinancialPriceSeries
        *     name="series2"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Candlestick"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume"
        * 	isTransitionInEnabled="true" />
        *
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * series.isTransitionInEnabled= true;
        * ```
        */
        get: function () {
            return this.i.m8;
        },
        set: function (v) {
            this.i.m8 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "isNegativeColorSupported", {
        /**
         * Overridden by derived series classes to indicate when negative colors are supported or not.
        */
        get: function () {
            return this.i.cz;
        },
        enumerable: true,
        configurable: true
    });
    IgrFinancialSeries.prototype.getPreviousOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.fb(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgrFinancialSeries.prototype.getNextOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.e9(toPoint(world), skipUnknowns);
        return (iv);
    };
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    *
    * The `getOffsetValue` method returns the offset value for this series if grouped on a category axis.
    *
    * ```ts
    * number offset= series.getOffsetValue();
    * ```
    */
    IgrFinancialSeries.prototype.getOffsetValue = function () {
        var iv = this.i.getOffsetValue();
        return (iv);
    };
    /**
     * Returns the width of the category grouping this series is in.
    
    *
    * The `getCategoryWidth` method returns the width of the category grouping this series is in.
    *
    * ```ts
    * number width = series.getCategoryWidth();
    * ```
    */
    IgrFinancialSeries.prototype.getCategoryWidth = function () {
        var iv = this.i.getCategoryWidth();
        return (iv);
    };
    IgrFinancialSeries.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.le(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgrFinancialSeries.prototype.getSeriesValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ek(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrFinancialSeries.prototype.getSeriesHighValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.eg(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrFinancialSeries.prototype.getSeriesLowValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ei(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrFinancialSeries.prototype.getSeriesCloseValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.nt(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrFinancialSeries.prototype.getSeriesOpenValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.nu(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrFinancialSeries.prototype.getSeriesVolumeValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.nv(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrFinancialSeries.prototype.getSeriesHighValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.la(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgrFinancialSeries.prototype.getSeriesLowValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.lc(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgrFinancialSeries.prototype.getSeriesOpenValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.o9(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgrFinancialSeries.prototype.getSeriesCloseValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.o8(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgrFinancialSeries.prototype.getSeriesVolumeValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.pa(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    *
    * Use `canUseAsYAxis` method to determine if the object can be used as YAxis.
    *
    * ```ts
    *   boolean canY =series.canUseAsYAxis(yAxis);
    * ```
    */
    IgrFinancialSeries.prototype.canUseAsYAxis = function (axis) {
        var iv = this.i.m3(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    *
    * Use `canUseAsXAxis` method to determine if the object can be used as XAxis.
    *
    * ```ts
    *   boolean canX =series.canUseAsXAxis(xAxis);
    * ```
    */
    IgrFinancialSeries.prototype.canUseAsXAxis = function (axis) {
        var iv = this.i.m2(axis);
        return (iv);
    };
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    *
    * The `getExactItemIndex` method gets the precise item index, if possible, based on the closeness to the previous or next whole integer.
    *
    * If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    *
    * ```ts
    * number index = series.getExactItemIndex(world);
    * ```
    */
    IgrFinancialSeries.prototype.getExactItemIndex = function (world) {
        var iv = this.i.d8(toPoint(world));
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    *
    * The `getItemIndex` method gets the index of the item that resides at the provided world coordinates.
    *
    * ```ts
    * number itemindex= series.getItemIndex(world);
    * ```
    */
    IgrFinancialSeries.prototype.getItemIndex = function (world) {
        var iv = this.i.e5(toPoint(world));
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    *
    * The `getItem` method gets the item that is the best match for the specified world coordinates.
    */
    IgrFinancialSeries.prototype.getItem = function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    IgrFinancialSeries.prototype.setNegativeColors = function (negativeBrush, negativeOutline) {
        this.i.jb(stringToBrush(negativeBrush), stringToBrush(negativeOutline));
    };
    Object.defineProperty(IgrFinancialSeries.prototype, "assigningCategoryStyle", {
        /**
         * Event raised when Assigning Category Style
        *
        * The `AssigningCategoryStyle` event raised when assigning Category Style.
        *
        * ```ts
        * series.assigningCategoryStyle= this.chart_AssigningCategoryStyle;
        * chart_AssigningCategoryStyle(sender :any,args: AssigningCategoryStyleEventArgs )
        *   {
        *
        *
        *   }
        * ```
        */
        get: function () {
            return this._assigningCategoryStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningCategoryStyle_wrapped !== null) {
                this.i.assigningCategoryStyle = delegateRemove(this.i.assigningCategoryStyle, this._assigningCategoryStyle_wrapped);
                this._assigningCategoryStyle_wrapped = null;
                this._assigningCategoryStyle = null;
            }
            this._assigningCategoryStyle = ev;
            this._assigningCategoryStyle_wrapped = function (o, e) {
                var outerArgs = new AssigningCategoryStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningCategoryStyle) {
                    _this.beforeAssigningCategoryStyle(_this, outerArgs);
                }
                if (_this._assigningCategoryStyle) {
                    _this._assigningCategoryStyle(_this, outerArgs);
                }
            };
            this.i.assigningCategoryStyle = delegateCombine(this.i.assigningCategoryStyle, this._assigningCategoryStyle_wrapped);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "typical", {
        /**
         * Handle this event in order to perform a custom typical price calculation.
        *
        * Use `Typical` event to perform a custom typical price calculation.
        *
        * ```ts
        * series.typical= this.chart_typical;
        *
        *   chart_typical(sender :any,args: FinancialEventArgs )
        *   {
        *
        *
        *   }
        * ```
        */
        get: function () {
            return this._typical;
        },
        set: function (ev) {
            var _this = this;
            if (this._typical_wrapped !== null) {
                this.i.typical = delegateRemove(this.i.typical, this._typical_wrapped);
                this._typical_wrapped = null;
                this._typical = null;
            }
            this._typical = ev;
            this._typical_wrapped = function (o, e) {
                var outerArgs = new FinancialEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeTypical) {
                    _this.beforeTypical(_this, outerArgs);
                }
                if (_this._typical) {
                    _this._typical(_this, outerArgs);
                }
            };
            this.i.typical = delegateCombine(this.i.typical, this._typical_wrapped);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrFinancialSeries.prototype, "typicalBasedOn", {
        /**
         * Handle this event in order to specify which columns the Typical price calculation is based on.
        *
        * Use `TypicalBasedOn` event to specify which columns the Typical price calculation is based on.
        *
        * ```ts
        *    series.typicalBasedOn= this.chart_typicalBasedOn;
        *     chart_typicalBasedOn(sender :any,args: FinancialEventArgs )
        *   {
        *
        *   }
        * ```
        */
        get: function () {
            return this._typicalBasedOn;
        },
        set: function (ev) {
            var _this = this;
            if (this._typicalBasedOn_wrapped !== null) {
                this.i.typicalBasedOn = delegateRemove(this.i.typicalBasedOn, this._typicalBasedOn_wrapped);
                this._typicalBasedOn_wrapped = null;
                this._typicalBasedOn = null;
            }
            this._typicalBasedOn = ev;
            this._typicalBasedOn_wrapped = function (o, e) {
                var outerArgs = new FinancialEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeTypicalBasedOn) {
                    _this.beforeTypicalBasedOn(_this, outerArgs);
                }
                if (_this._typicalBasedOn) {
                    _this._typicalBasedOn(_this, outerArgs);
                }
            };
            this.i.typicalBasedOn = delegateCombine(this.i.typicalBasedOn, this._typicalBasedOn_wrapped);
        },
        enumerable: true,
        configurable: true
    });
    return IgrFinancialSeries;
}(IgrSeries));
export { IgrFinancialSeries };
