import * as tslib_1 from "tslib";
import { MarkerType_$type } from "./MarkerType";
import { IgrSeries } from "./igr-series";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents the base class for series containing markers.
*
* MarkerSeries represents the base class for series containing markers.
*
* Example:
*/
var IgrMarkerSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrMarkerSeries, _super);
    function IgrMarkerSeries(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrMarkerSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "hasMarkers", {
        /**
         * Returns whether the current series supports visual markers.
        *
        * `hasMarkers` property is overriden, it returns whether the current series supports visual markers. You can use it like this:
        *
        * ```ts
        *  let gotMarkers: boolean = this.series.hasMarkers;
        * ```
        */
        get: function () {
            return this.i.hasMarkers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        *
        * `markerType` property gets or sets the marker type for the current series object. For example, you can set it like this:
        */
        get: function () {
            return this.i.lu;
        },
        set: function (v) {
            this.i.lu = ensureEnum(MarkerType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        *
        * `markerTemplate` property gets or sets the MarkerTemplate for the current series object. For example, you can use it like this:
        */
        get: function () {
            return this.i.md;
        },
        set: function (v) {
            this.i.md = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        *
        * `actualMarkerTemplate` property gets the effective marker template for the current series object. You can use it like this:
        */
        get: function () {
            return this.i.mb;
        },
        set: function (v) {
            this.i.mb = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        *
        * `markerBrush` property gets or sets the brush that specifies how the current series object's marker interiors are painted. You can use it like this:
        */
        get: function () {
            return brushToString(this.i.mq);
        },
        set: function (v) {
            this.i.mq = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        *
        * `actualMarkerBrush` property gets the effective marker brush for the current series object. For example, you can use it like this:
        *
        * ```ts
        *  let effectiveMarkerBrush: string = this.series.actualMarkerBrush;
        *
        * ```
        */
        get: function () {
            return brushToString(this.i.mo);
        },
        set: function (v) {
            this.i.mo = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        *
        * `markerOutline` property gets or sets the brush that specifies how the current series object's marker outlines are painted. You can use it like this:
        */
        get: function () {
            return brushToString(this.i.mr);
        },
        set: function (v) {
            this.i.mr = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        *
        * `actualMarkerOutline` property gets the effective marker outline for the current series object. You can use it like this:
        *
        * ```ts
        *  let effectiveMarkerOutline: string = this.series.actualMarkerOutline;
        *
        * ```
        */
        get: function () {
            return brushToString(this.i.mp);
        },
        set: function (v) {
            this.i.mp = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    return IgrMarkerSeries;
}(IgrSeries));
export { IgrMarkerSeries };
