/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { IgrNumericAngleAxis } from './igr-numeric-angle-axis';
import { IgrNumericRadiusAxis } from './igr-numeric-radius-axis';
import { IgrMarkerSeries } from './igr-marker-series';
import { brushToString, stringToBrush, toPoint, ensureBool, ensureEnum } from "igniteui-react-core/ES5/componentUtil";
import { TrendLineType_$type } from "igniteui-react-core/ES5/TrendLineType";
/**
 * Represents the base class from which all IgxDataChartComponent polar series are derived.
*/
var IgrPolarBase = /** @class */ (function (_super) {
    tslib_1.__extends(IgrPolarBase, _super);
    function IgrPolarBase(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrPolarBase.prototype, "angleAxisName", {
        get: function () {
            return this._angleAxisName;
        },
        set: function (value) {
            this._angleAxisName = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "radiusAxisName", {
        get: function () {
            return this._radiusAxisName;
        },
        set: function (value) {
            this._radiusAxisName = value;
        },
        enumerable: true,
        configurable: true
    });
    IgrPolarBase.prototype.bindAxes = function (axes) {
        for (var i = 0; i < axes.length; i++) {
            if (axes[i].name == this.angleAxisName) {
                this.angleAxis = axes[i];
            }
            if (axes[i].name == this.radiusAxisName) {
                this.radiusAxis = axes[i];
            }
        }
    };
    Object.defineProperty(IgrPolarBase.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "isPolar", {
        /**
     * Checks if this series is a polar series
    */
        get: function () {
            return this.i.c0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "angleMemberPath", {
        /**
         * Gets or sets the path to use to find the angle values for the series.
        */
        get: function () {
            return this.i.np;
        },
        set: function (v) {
            this.i.np = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "radiusMemberPath", {
        /**
         * Gets or sets the path to use to get the radius values for the series.
        */
        get: function () {
            return this.i.nv;
        },
        set: function (v) {
            this.i.nv = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "angleAxis", {
        /**
         * Gets the effective angle axis for the current series object.
        */
        get: function () {
            if (this.i.mw == null) {
                return null;
            }
            if (!this.i.mw.externalObject) {
                var e = new IgrNumericAngleAxis(null);
                e._implementation = this.i.mw;
                this.i.mw.externalObject = e;
            }
            return this.i.mw.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mw = null : this.i.mw = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "radiusAxis", {
        /**
         * Gets the effective radius axis for the current series object.
        */
        get: function () {
            if (this.i.mx == null) {
                return null;
            }
            if (!this.i.mx.externalObject) {
                var e = new IgrNumericRadiusAxis(null);
                e._implementation = this.i.mx;
                this.i.mx.externalObject = e;
            }
            return this.i.mx.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mx = null : this.i.mx = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "useCartesianInterpolation", {
        /**
         * Gets or sets whether Cartesian Interpolation should be used rather than Archimedian
         * spiral based interpolation.
        */
        get: function () {
            return this.i.nh;
        },
        set: function (v) {
            this.i.nh = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "maximumMarkers", {
        /**
         * Gets or sets the maximum number of markers displayed by the current series.
         * If more than the specified number of markers are visible, the polar series will automatically
         * choose a representative set.
        */
        get: function () {
            return this.i.nk;
        },
        set: function (v) {
            this.i.nk = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "trendLineType", {
        /**
         * Gets or sets the trend type for the current series object.
        */
        get: function () {
            return this.i.m8;
        },
        set: function (v) {
            this.i.m8 = ensureEnum(TrendLineType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "trendLineBrush", {
        /**
         * Gets or sets the brush that specifies how the current series
         * object's trend line is drawn.
        */
        get: function () {
            return brushToString(this.i.ol);
        },
        set: function (v) {
            this.i.ol = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "actualTrendLineBrush", {
        /**
         * Gets the effective TrendLineBrush for this series.
        */
        get: function () {
            return brushToString(this.i.ok);
        },
        set: function (v) {
            this.i.ok = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "trendLineThickness", {
        /**
         * Gets or sets the thickness of the current series object's trend line.
        */
        get: function () {
            return this.i.nj;
        },
        set: function (v) {
            this.i.nj = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "trendLinePeriod", {
        /**
         * Gets or sets the moving average period for the current series object.
        */
        get: function () {
            return this.i.nl;
        },
        set: function (v) {
            this.i.nl = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "trendLineZIndex", {
        /**
         * Sets or Gets the Trendline Z index.
        */
        get: function () {
            return this.i.nm;
        },
        set: function (v) {
            this.i.nm = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrPolarBase.prototype, "clipSeriesToBounds", {
        /**
         * Gets or sets whether to clip the series to the bounds.
         * Setting this to true can effect performance.
        */
        get: function () {
            return this.i.nf;
        },
        set: function (v) {
            this.i.nf = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    /**
 * Scrolls the requested item into view, if possible.

* @param item  * The item to scroll into view.
*/
    IgrPolarBase.prototype.scrollIntoView = function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrPolarBase.prototype.getItem = function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    IgrPolarBase.prototype.getItemIndex = function (world) {
        var iv = this.i.e5(toPoint(world));
        return (iv);
    };
    /**
     * Determine if object can be used as RadiusAxis
    
    * @param axis  * The object to check
    */
    IgrPolarBase.prototype.canUseAsRadiusAxis = function (axis) {
        var iv = this.i.ne(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    IgrPolarBase.prototype.canUseAsAngleAxis = function (axis) {
        var iv = this.i.nd(axis);
        return (iv);
    };
    return IgrPolarBase;
}(IgrMarkerSeries));
export { IgrPolarBase };
