import { IgrNumericXAxis } from "./igr-numeric-x-axis";
import { IgrCategoryYAxis } from "./igr-category-y-axis";
import { IgrStackedSeriesBase, IIgrStackedSeriesBaseProps } from "./igr-stacked-series-base";
import { VerticalStackedSeriesBase } from "./VerticalStackedSeriesBase";
import { IgrAxis } from './igr-axis';
/**
 * Base class for stacked series with a numeric x-axis and a category y-axis.
*/
export declare abstract class IgrVerticalStackedSeriesBase<P extends IIgrVerticalStackedSeriesBaseProps = IIgrVerticalStackedSeriesBaseProps> extends IgrStackedSeriesBase<P> {
    constructor(props: P);
    private _xAxisName;
    xAxisName: string;
    private _yAxisName;
    yAxisName: string;
    bindAxes(axes: IgrAxis[]): void;
    readonly i: VerticalStackedSeriesBase;
    /**
 * Gets or sets the effective x-axis for the current CategorySeries object.
*/
    xAxis: IgrNumericXAxis;
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    */
    yAxis: IgrCategoryYAxis;
    /**
     * Gets whether or not the current series is vertical series
    */
    readonly isVertical: boolean;
    /**
 * Returns the offset value for this series if grouped on a category axis.

*/
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
}
export interface IIgrVerticalStackedSeriesBaseProps extends IIgrStackedSeriesBaseProps {
    xAxisName?: string;
    yAxisName?: string;
    /**
 * Gets or sets the effective x-axis for the current CategorySeries object.
*/
    xAxis?: IgrNumericXAxis;
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    */
    yAxis?: IgrCategoryYAxis;
}
