import * as tslib_1 from "tslib";
import { IgrHorizontalAnchoredCategorySeries } from "./igr-horizontal-anchored-category-series";
import { WaterfallSeries } from "./WaterfallSeries";
import { brushToString, stringToBrush, toPoint, fromRect } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent waterfall column series.
*
* `IgrWaterfallSeries` belongs to a group of `IgrCategorySeries` and it is rendered using a collection of vertical columns that show the difference between consecutive data points.
*/
var IgrWaterfallSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrWaterfallSeries, _super);
    function IgrWaterfallSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrWaterfallSeries.prototype.createImplementation = function () {
        return new WaterfallSeries();
    };
    Object.defineProperty(IgrWaterfallSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrWaterfallSeries.prototype, "isNegativeColorSupported", {
        /**
         * Overridden by derived series classes to indicate when negative colors are supported or not.
        */
        get: function () {
            return this.i.cz;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrWaterfallSeries.prototype, "negativeBrush", {
        /**
         * Gets or sets the brush to use for negative portions of the series.
        *
        * Gets or sets the color used to draw negative declines in values for this `IgrWaterfallSeries`.
        */
        get: function () {
            return brushToString(this.i.ql);
        },
        set: function (v) {
            this.i.ql = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrWaterfallSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        *
        * Gets or sets the amount to round corners in the direction of the X axis in this series.
        */
        get: function () {
            return this.i.qb;
        },
        set: function (v) {
            this.i.qb = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrWaterfallSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        *
        * Gets or sets the amount to round corners in the direction of the Y axis in this series.
        */
        get: function () {
            return this.i.qc;
        },
        set: function (v) {
            this.i.qc = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrWaterfallSeries.prototype, "negativeOutline", {
        /**
         * Brush to use for outlining negative elements in the waterfall series.
        *
        * Gets or sets the color used to draw borders of negative declines in values for this `IgrWaterfallSeries`.
        */
        get: function () {
            return brushToString(this.i.qm);
        },
        set: function (v) {
            this.i.qm = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    IgrWaterfallSeries.prototype.setNegativeColors = function (negativeBrush, negativeOutline) {
        this.i.jb(stringToBrush(negativeBrush), stringToBrush(negativeOutline));
    };
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    *
    * Returns a bounding box `Rect` for a data value given a `Point`.
    */
    IgrWaterfallSeries.prototype.getSeriesValueBoundingBox = function (world) {
        var iv = this.i.ln(toPoint(world));
        return fromRect(iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    *
    * Returns the width of items in the `IgrWaterfallSeries`.
    *
    * ```ts
    * let itemSpan: number = series.GetItemSpan();
    * ```
    */
    IgrWaterfallSeries.prototype.getItemSpan = function () {
        var iv = this.i.ed();
        return (iv);
    };
    return IgrWaterfallSeries;
}(IgrHorizontalAnchoredCategorySeries));
export { IgrWaterfallSeries };
