import { IgrStrategyBasedIndicator, IIgrStrategyBasedIndicatorProps } from "./igr-strategy-based-indicator";
import { WilliamsPercentRIndicator } from "./WilliamsPercentRIndicator";
/**
 * Represents a IgxDataChartComponent Williams %R indicator series.
 * Default required members: High, Low, Close
*
* The `IgrWilliamsPercentRIndicator` scale ranges from 0 to -100. It is useful for identifying overbought and oversold securities.
* The `IgrWilliamsPercentRIndicator` is calculated by dividing the difference between the highest high for the period and the current close by the highest high minus the lowest low for the period.
*/
export declare class IgrWilliamsPercentRIndicator extends IgrStrategyBasedIndicator<IIgrWilliamsPercentRIndicatorProps> {
    protected createImplementation(): WilliamsPercentRIndicator;
    readonly i: WilliamsPercentRIndicator;
    constructor(props: IIgrWilliamsPercentRIndicatorProps);
    /**
     * Gets or sets the moving average period for the current StandardDeviationIndicator object.
     * The typical, and initial, value for Williams %R periods is 14.
    *
    * Gets or sets the `period` for the moving average period.
    *
    * The typical, and initial, value for Williams %R periods is 14.
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    period: number;
}
export interface IIgrWilliamsPercentRIndicatorProps extends IIgrStrategyBasedIndicatorProps {
    /**
     * Gets or sets the moving average period for the current StandardDeviationIndicator object.
     * The typical, and initial, value for Williams %R periods is 14.
    *
    * Gets or sets the `period` for the moving average period.
    *
    * The typical, and initial, value for Williams %R periods is 14.
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    period?: number | string;
}
